@@ -8,9 +8,18 @@ def main(cli_args=None):
     if not cli_args:
         cli_args = sys.argv[1:]
     cmd = os.path.abspath(
-        os.path.join(os.path.dirname(__file__),
-                     '..',
-                     '%s.sh' % os.path.basename(__file__)[0: -3]))
+        os.path.join(
+            os.path.dirname(__file__), '%s.sh' % os.path.basename(__file__)[0:-3]
+        )
+    )
+    if not os.path.isfile(cmd):
+        cmd = os.path.abspath(
+            os.path.join(
+                os.path.dirname(__file__),
+                '..',
+                '%s.sh' % os.path.basename(__file__)[0:-3]
+            )
+        )
     if not os.path.isfile(cmd):
         print('Internal package error: file %s not found!' % cmd)
     for arg in cli_args:
